==> ecs-1.60.0-sources.jar: software/amazon/awscdk/services/ecs/EcsOptimizedAmiProps.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The properties that define which ECS-optimized AMI is used.
 * <p>
 * @deprecated see {@link EcsOptimizedImage}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:33.003Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.EcsOptimizedAmiProps")
@software.amazon.jsii.Jsii.Proxy(EcsOptimizedAmiProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface EcsOptimizedAmiProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The Amazon Linux generation to use.
     * <p>
     * Default: AmazonLinuxGeneration.AmazonLinux2
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.AmazonLinuxGeneration getGeneration() {
        return null;
    }

    /**
     * The ECS-optimized AMI variant to use.
     * <p>
     * Default: AmiHardwareType.Standard
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.AmiHardwareType getHardwareType() {
        return null;
    }

    /**
     * The Windows Server version to use.
     * <p>
     * Default: none, uses Linux generation
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.WindowsOptimizedVersion getWindowsVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<EcsOptimizedAmiProps> {
        private software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation;
        private software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType;
        private software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion;

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getGeneration}
         * @param generation The Amazon Linux generation to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder generation(software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation) {
            this.generation = generation;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getHardwareType}
         * @param hardwareType The ECS-optimized AMI variant to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder hardwareType(software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType) {
            this.hardwareType = hardwareType;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getWindowsVersion}
         * @param windowsVersion The Windows Server version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder windowsVersion(software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            this.windowsVersion = windowsVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EcsOptimizedAmiProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public EcsOptimizedAmiProps build() {
            return new Jsii$Proxy(generation, hardwareType, windowsVersion);
        }
    }

    /**
     * An implementation for {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EcsOptimizedAmiProps {
        private final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation;
        private final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType;
        private final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.generation = this.jsiiGet("generation", software.amazon.awscdk.services.ec2.AmazonLinuxGeneration.class);
            this.hardwareType = this.jsiiGet("hardwareType", software.amazon.awscdk.services.ecs.AmiHardwareType.class);
            this.windowsVersion = this.jsiiGet("windowsVersion", software.amazon.awscdk.services.ecs.WindowsOptimizedVersion.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation, final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType, final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.generation = generation;
            this.hardwareType = hardwareType;
            this.windowsVersion = windowsVersion;
        }

        @Override
        public software.amazon.awscdk.services.ec2.AmazonLinuxGeneration getGeneration() {
            return this.generation;
        }

        @Override
        public software.amazon.awscdk.services.ecs.AmiHardwareType getHardwareType() {
            return this.hardwareType;
        }

        @Override
        public software.amazon.awscdk.services.ecs.WindowsOptimizedVersion getWindowsVersion() {
            return this.windowsVersion;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getGeneration() != null) {
                data.set("generation", om.valueToTree(this.getGeneration()));
            }
            if (this.getHardwareType() != null) {
                data.set("hardwareType", om.valueToTree(this.getHardwareType()));
            }
            if (this.getWindowsVersion() != null) {
                data.set("windowsVersion", om.valueToTree(this.getWindowsVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.EcsOptimizedAmiProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EcsOptimizedAmiProps.Jsii$Proxy that = (EcsOptimizedAmiProps.Jsii$Proxy) o;

            if (this.generation != null ? !this.generation.equals(that.generation) : that.generation != null) return false;
            if (this.hardwareType != null ? !this.hardwareType.equals(that.hardwareType) : that.hardwareType != null) return false;
            return this.windowsVersion != null ? this.windowsVersion.equals(that.windowsVersion) : that.windowsVersion == null;
        }

        @Override
        public int hashCode() {
            int result = this.generation != null ? this.generation.hashCode() : 0;
            result = 31 * result + (this.hardwareType != null ? this.hardwareType.hashCode() : 0);
            result = 31 * result + (this.windowsVersion != null ? this.windowsVersion.hashCode() : 0);
            return result;
        }
    }
}

==> ecs-1.100.0-sources.jar: software/amazon/awscdk/services/ecs/EcsOptimizedAmiProps.java <==
package software.amazon.awscdk.services.ecs;

/**
 * (deprecated) The properties that define which ECS-optimized AMI is used.
 * <p>
 * @deprecated see {@link EcsOptimizedImage}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:41.800Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.EcsOptimizedAmiProps")
@software.amazon.jsii.Jsii.Proxy(EcsOptimizedAmiProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
public interface EcsOptimizedAmiProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * (deprecated) The Amazon Linux generation to use.
     * <p>
     * Default: AmazonLinuxGeneration.AmazonLinux2
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.AmazonLinuxGeneration getGeneration() {
        return null;
    }

    /**
     * (deprecated) The ECS-optimized AMI variant to use.
     * <p>
     * Default: AmiHardwareType.Standard
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.AmiHardwareType getHardwareType() {
        return null;
    }

    /**
     * (deprecated) The Windows Server version to use.
     * <p>
     * Default: none, uses Linux generation
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    default @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.WindowsOptimizedVersion getWindowsVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<EcsOptimizedAmiProps> {
        private software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation;
        private software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType;
        private software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion;

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getGeneration}
         * @param generation The Amazon Linux generation to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder generation(software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation) {
            this.generation = generation;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getHardwareType}
         * @param hardwareType The ECS-optimized AMI variant to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder hardwareType(software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType) {
            this.hardwareType = hardwareType;
            return this;
        }

        /**
         * Sets the value of {@link EcsOptimizedAmiProps#getWindowsVersion}
         * @param windowsVersion The Windows Server version to use.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder windowsVersion(software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            this.windowsVersion = windowsVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EcsOptimizedAmiProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public EcsOptimizedAmiProps build() {
            return new Jsii$Proxy(generation, hardwareType, windowsVersion);
        }
    }

    /**
     * An implementation for {@link EcsOptimizedAmiProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EcsOptimizedAmiProps {
        private final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation;
        private final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType;
        private final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.generation = software.amazon.jsii.Kernel.get(this, "generation", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.AmazonLinuxGeneration.class));
            this.hardwareType = software.amazon.jsii.Kernel.get(this, "hardwareType", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.AmiHardwareType.class));
            this.windowsVersion = software.amazon.jsii.Kernel.get(this, "windowsVersion", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.WindowsOptimizedVersion.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation, final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType, final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.generation = generation;
            this.hardwareType = hardwareType;
            this.windowsVersion = windowsVersion;
        }

        @Override
        public final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration getGeneration() {
            return this.generation;
        }

        @Override
        public final software.amazon.awscdk.services.ecs.AmiHardwareType getHardwareType() {
            return this.hardwareType;
        }

        @Override
        public final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion getWindowsVersion() {
            return this.windowsVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getGeneration() != null) {
                data.set("generation", om.valueToTree(this.getGeneration()));
            }
            if (this.getHardwareType() != null) {
                data.set("hardwareType", om.valueToTree(this.getHardwareType()));
            }
            if (this.getWindowsVersion() != null) {
                data.set("windowsVersion", om.valueToTree(this.getWindowsVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-ecs.EcsOptimizedAmiProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EcsOptimizedAmiProps.Jsii$Proxy that = (EcsOptimizedAmiProps.Jsii$Proxy) o;

            if (this.generation != null ? !this.generation.equals(that.generation) : that.generation != null) return false;
            if (this.hardwareType != null ? !this.hardwareType.equals(that.hardwareType) : that.hardwareType != null) return false;
            return this.windowsVersion != null ? this.windowsVersion.equals(that.windowsVersion) : that.windowsVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.generation != null ? this.generation.hashCode() : 0;
            result = 31 * result + (this.hardwareType != null ? this.hardwareType.hashCode() : 0);
            result = 31 * result + (this.windowsVersion != null ? this.windowsVersion.hashCode() : 0);
            return result;
        }
    }
}
